Modular Forms
=============

This section is about computing with modular forms, modular symbols,
and modular abelian varieties. Most of the Sage functionality we
describe below is new code written for Sage by myself, Craig Citro,
Robert Bradshaw, and Jordi Quer in consultation with John Cremona. It
has much overlap in functionality with the modular forms code in
Magma, which I developed during 1998-2004.

.. toctree::
   :maxdepth: 2

   modular_forms_and_hecke_operators
   modular_symbols
   method_of_graphs
   level_one_forms
   half_integral
   generators_for_rings
   l_series
   modabvar
